#pragma once

namespace vcpkg
{
    struct SanitizedUrl;
    struct AssetCachingSettings;
}
